/* maximal set of features without FFTW library */
#define PARTIAL_PERIODIC
#define ELECTROSTATICS
#define ROTATION
#define ROTATIONAL_INTERIA
#define DIPOLES
#define EXTERNAL_FORCES
#define CONSTRAINTS
#define MASS
#define EXCLUSIONS
#define COMFORCE
#define COMFIXED
#define MOLFORCES
#define BOND_VIRTUAL
#define GRANDCANONICAL

#define NEMD
#define NPT 

#define LB
#define LB_BOUNDARIES
#define LB_ELECTROHYDRODYNAMICS

#define TABULATED
#define LENNARD_JONES
#define LENNARD_JONES_GENERIC
#define LJCOS
#define LJCOS2
#define LJ_ANGLE
#define GAY_BERNE
#define SMOOTH_STEP
#define HERTZIAN
#define BMHTF_NACL
#define MORSE
#define BUCKINGHAM
#define SOFT_SPHERE
#define INTER_RF

#define BOND_ANGLE
#define BOND_ANGLEDIST

#define VIRTUAL_SITES_RELATIVE
